*     JLdL 02Jan21.
*     
*     Copyright (C) 2020-2021 by Jorge L. deLyra <delyra@lmail.if.usp.br>.
*     This program can be copied and/or distributed freely under the
*     GPL license; see the terms and conditions in the files within
*     the sub-directory doc/ of this source directory.
*     
*     A function to return the value of the derivative of the
*     integrand of the integral that is shown in Equations (30)
*     and (31) of the paper; the variables passed are:
*     
*     xi2_var_loc : the outer shell radius \xi_{2};
*     xim_var_loc : the Schwarzschild radius \xi_{M};
*     xi_var_loc  : the radius variable \xi;
*     lflg_error  ; an error flag (output).
*     
*     This routine uses the following additional local
*     double-precision temporary variables:
*     
*     polynomial_loc : local temporary for the polynomial;
*     deriv_num_loc  : local temporary for the numerator;
*     deriv_den_loc  : local temporary for the denominator;
*     derivative_loc : local temporary for the derivative.
*     
*     The derivative, with the polynomial in the denominator,
*     is given by (LaTeX codes):
*     
*     \xi^{3/2} [ 4 \xi^{3} + 6 \xi + 5 ( \xi_{2}^{3} - 3 \xi_{M} ) ]
*     ---------------------------------------------------------------
*     .   2 [ \xi_{2}^{3} - \xi^{3} + 3 ( \xi - \xi_{M} ) ]^{5/2}
*     
*     Complex formulas contained in this routine: the derivative.
*     
      FUNCTION DERIVATIVE_FUN
     *     (xi2_var_loc
     *     ,xim_var_loc
     *     ,xi_var_loc
     *     ,lflg_error)
*     
*     Double precision everything; due to the gfortran compiler option
*     -fdefault-real-8, which is in use in the Makefile, this is actually
*     quadruple precision, in the traditional sense of the term, that is,
*     it is actually real*16 (128-bit real data).
      implicit double precision (a-h,o-z)
*     
*     Initialize the error flag.
      lflg_error=0
*     
*     Calculate the function.
*     
*     Calculate the numerator.
      deriv_num_loc=4.0d0*xi_var_loc**3
      deriv_num_loc=deriv_num_loc+6.0d0*xi_var_loc
      deriv_num_loc=deriv_num_loc+5.0d0*xi2_var_loc**3
      deriv_num_loc=deriv_num_loc-15.0d0*xim_var_loc
      deriv_num_loc=deriv_num_loc*dsqrt(xi_var_loc)**3
*     
*     Retrieve the value of the polynomial.
      polynomial_loc=
     *     polynomial_fun
     *     (xi2_var_loc
     *     ,xim_var_loc
     *     ,xi_var_loc)
*     
*     Check the strict positivity condition; if this does not succeed,
*     then write out an error message, raise the error flag, zero off
*     the function, and return prematurely in error.
      if (polynomial_loc.le.0.0d0) then
         write(*,*)
         write(*,*) 'DERIVATIVE_FUN ERROR:'
         write(*,*) '       cubic polynomial not strictly positive'
         write(*,*) '       at \xi and/or at \xi_{2}, where'
         write(*,*) '       \xi     = ',xi_var_loc
         write(*,*) '       \xi_{2} = ',xi2_var_loc
         write(*,*) '       \xi_{M} = ',xim_var_loc
         write(*,*) '       Therefore, the derivative does not exist'
         write(*,*)
         lflg_error=1
         derivative_loc=0.0d0
         derivative_fun=derivative_loc
         return
      end if
*     
*     Calculate the denominator.
      deriv_den_loc=2.0d0*dsqrt(polynomial_loc)**5
*     
*     Calculate the ratio.
      derivative_loc=deriv_num_loc/deriv_den_loc
*     
*     Pass the function.
      derivative_fun=derivative_loc
*     
      return
*     
      END
